==> automium-0.2.2.zip: automium-0.2.2/src/atm/load.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Automium System
# Copyright (C) 2008-2014 Hive Solutions Lda.
#
# This file is part of Hive Automium System.
#
# Hive Automium System is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Automium System is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Automium System. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2014 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import urllib2
import urlparse

DEFAULT_NAME = "download"
""" The default name to be used for the file in case
no name is possible to be extracted from the url """

def download(url, file_path = None):
    url_p = urlparse.urlparse(url)
    path = url_p.path

    file_path = file_path or os.path.basename(path)
    file_path = file_path or DEFAULT_NAME

    response = urllib2.urlopen(url)
    contents = response.read()

    file = open(file_path, "wb")
    try: file.write(contents)
    finally: file.close()

==> automium-0.2.6.zip: automium-0.2.6/src/atm/load.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Hive Automium System
# Copyright (C) 2008-2014 Hive Solutions Lda.
#
# This file is part of Hive Automium System.
#
# Hive Automium System is free software: you can redistribute it and/or modify
# it under the terms of the Apache License as published by the Apache
# Foundation, either version 2.0 of the License, or (at your option) any
# later version.
#
# Hive Automium System is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# Apache License for more details.
#
# You should have received a copy of the Apache License along with
# Hive Automium System. If not, see <http://www.apache.org/licenses/>.

__author__ = "João Magalhães <joamag@hive.pt>"
""" The author(s) of the module """

__version__ = "1.0.0"
""" The version of the module """

__revision__ = "$LastChangedRevision$"
""" The revision number of the module """

__date__ = "$LastChangedDate$"
""" The last change date of the module """

__copyright__ = "Copyright (c) 2008-2014 Hive Solutions Lda."
""" The copyright for the module """

__license__ = "Apache License, Version 2.0"
""" The license for the module """

import os
import legacy

DEFAULT_NAME = "download"
""" The default name to be used for the file in case
no name is possible to be extracted from the url """

def download(url, file_path = None):
    url_p = legacy.urlparse(url)
    path = url_p.path

    file_path = file_path or os.path.basename(path)
    file_path = file_path or DEFAULT_NAME

    response = legacy.urlopen(url)
    contents = response.read()

    file = open(file_path, "wb")
    try: file.write(contents)
    finally: file.close()
